/**************************************************************************//**
 * @file
 * @brief Basic board test/demo routines
 * @author shondll
 * @version 1.1.1
 ******************************************************************************
 *
 *****************************************************************************/
#include <stdio.h>
#include <stdbool.h>
#include <string.h>
#include <stdlib.h>
#include "efm32.h"
#include "bsp.h"

#define BUTTON_SETTLE_TIME 10

/** SysTick polled Delay routine */
extern void Delay(uint32_t dlyTicks);

static volatile bool enableRtcBlink = true;
static volatile uint32_t batteryLevel;

/**************************************************************************//**
 * @brief Board Test Routine, blink LEDs
 *****************************************************************************/
void Board_Test(void)
{
	
	int counter = BUTTON_SETTLE_TIME;
	
	while(1) {
		if( BTN_PRESSED() ) {
			if(counter) {
				if( !(--counter) ) {
					enableRtcBlink = !enableRtcBlink;
				}
			}
		} else {
			counter = BUTTON_SETTLE_TIME;
		}
		
		
		// display battery level noiw and then
		if(batteryLevel > 1000) { // means that battery is connected
	       float val = (float)batteryLevel;
		   batteryLevel = 0;
		
		   val = (1.25 * val * 4.0) / 4096.0;
		
		   printf("\nBatt voltage: %.3fV", val);
		}
		
		Delay(2);
	}	
}

/* call every half second */
void ClockUpdate(void)
{
	static int adcStartCnt = 0;
	
	// toggle LED1
	if(enableRtcBlink) {
		LED_TOGGLE();
	}
	
	// enable another measuring of the battery level
	if(++adcStartCnt > 5) {
		adcStartCnt = 0;
		ADC_TypeDef *adc = ADC0;
		adc->CMD |= ADC_CMD_SINGLESTART; // start convertion
	}
}

/* called when convertion of the battery level is complete */
void ADC0_IRQHandler(void)
{
	/* Clear interrupt source */
	ADC0->IFC = ADC_IFC_SINGLE;
	
	batteryLevel = ADC0->SINGLEDATA;
}